# Configuration

::: casty.CastyConfig

::: casty.load_config

::: casty.discover_config

::: casty.ActorConfig

::: casty.MailboxConfig

::: casty.SupervisionConfig

::: casty.ShardingConfig

::: casty.FailureDetectorConfig

::: casty.GossipConfig

::: casty.HeartbeatConfig

::: casty.TransportConfig

::: casty.ResolvedActorConfig
